<?php
namespace bwdsb_switch_background_namespace\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class bwdsb_switchbackground_widgets extends Widget_Base {

    public function get_name() {
		return esc_html__( 'bwdsb-switchbackground', 'bwdsb-switch-backgroundtd' );
	}

	public function get_title() {
		return esc_html__( 'Background Switcher', 'bwdsb-switch-backgroundtd' );
	}

	public function get_icon() {
		return 'bwdsb-switchbackground-icon';
	}

	public function get_categories() {
		return [ 'bwdsb-switch-background-category' ];
	}

    protected function register_controls(){
		

		$this->start_controls_section(
			'bwdsb_common_section',
			[
				'label' => esc_html__( 'Common', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		//Select Style
		$this->add_control(
			'bwdsb_select_style_selection',
			[
				'label' => esc_html__( 'Select Style', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__( 'Style 1', 'bwdsb-switch-backgroundtd' ),
					'style2' => esc_html__( 'Style 2', 'bwdsb-switch-backgroundtd' ),
					'style3' => esc_html__( 'Style 3', 'bwdsb-switch-backgroundtd' ),
					'style4' => esc_html__( 'Style 4', 'bwdsb-switch-backgroundtd' ),
					'style5' => esc_html__( 'Style 5', 'bwdsb-switch-backgroundtd' ),
					'style6' => esc_html__( 'Style 6', 'bwdsb-switch-backgroundtd' ),
					'style7' => esc_html__( 'Style 7', 'bwdsb-switch-backgroundtd' ),
					'style8' => esc_html__( 'Style 8', 'bwdsb-switch-backgroundtd' ),
					'style9' => esc_html__( 'Style 9', 'bwdsb-switch-backgroundtd' ),
					'style10' => esc_html__( 'Style 10', 'bwdsb-switch-backgroundtd' ),
					'style11' => esc_html__( 'Style 11', 'bwdsb-switch-backgroundtd' ),
					'style12' => esc_html__( 'Style 12', 'bwdsb-switch-backgroundtd' ),
					'style13' => esc_html__( 'Style 13', 'bwdsb-switch-backgroundtd' ),
					'style14' => esc_html__( 'Style 14', 'bwdsb-switch-backgroundtd' ),
				],
			]
		);

        $this->add_control(
			'bwdsb_mouse_event',
			[
				'label'     => esc_html__('Mouse Event Type', 'bwdsb-switch-backgroundtd'),
				'type'      => Controls_Manager::SELECT,
				'default' => 'mouseenter',
				'options'   => [
					'mouseenter' => esc_html__('Mouse Enter', 'bwdsb-switch-backgroundtd'),
					'mouseleave' => esc_html__('Mouse Leave', 'bwdsb-switch-backgroundtd'),
					'click' => esc_html__('Click', 'bwdsb-switch-backgroundtd'),
					'dblclick' => esc_html__('Double Click', 'bwdsb-switch-backgroundtd'),
				],
			]
		);

		//select
		$this->add_control(
			'bwdsb_switch_layout_style',
			[
				'label' => esc_html__( 'Layout Style', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'flex',
				'options' => [
					'flex'  => esc_html__( 'flex', 'bwdsb-switch-backgroundtd' ),
					'grid'  => esc_html__( 'grid', 'bwdsb-switch-backgroundtd' ),
				],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-style-common' => 'display: {{VALUE}}!important;',
				],
			]
		);

		$this->add_control(
			'bwdsb_switch_layout_style_flex',
			[
				'label'         => esc_html__('Direction', 'bwdsb-switch-backgroundtd'),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''    => esc_html__('Horizontal', 'bwdsb-switch-backgroundtd'),
					'column'      => esc_html__('Vertical', 'bwdsb-switch-backgroundtd'),
				],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-style-common' => 'flex-direction: {{VALUE}}!important;',
				],
				'condition' => [
					'bwdsb_switch_layout_style' => 'flex',
				],
			]
		);

		$this->add_responsive_control(
			'bwdsb_switch_layout_style_grid',
			[
				'label'       => esc_html__('Grid Columns', 'bwdsb-switch-backgroundtd'),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 0,
				'max'         => 10000,
				'step'        => 1,
				'default'     => 2,
				'selectors'   => [
					'{{WRAPPER}} .bwdsb-style-common' => 'grid-template-columns: repeat({{SIZE}}, minmax(0, 1fr))',
				],
				'condition' => [
					'bwdsb_switch_layout_style' => 'grid',
				],
			]
		);

        //breakpoint--------------------
		$this->add_control(
			'bwdsb_switch_breakpoint',
			[
				'label'       => esc_html__('Responsive Breakpoint', 'bwdsb-switch-backgroundtd'),
                'description' => esc_html__( 'For Horizontal Layout Only', 'bwdsb-switch-backgroundtd' ),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 0,
				'max'         => 10000,
				'step'        => 1,
                'condition' => [
					'bwdsb_switch_layout_style' => 'flex',
					'bwdsb_switch_layout_style_flex' => '',
				],
			]
		);
        $this->add_control(
			'bwdsb_switch_item_width_breakpointout',
			[
				'label'       => esc_html__('Item Box Width', 'bwdsb-switch-backgroundtd'),
                'description' => esc_html__( 'When using a responsive breakpoint, you will need to provide custom item box width. ', 'bwdsb-switch-backgroundtd' ),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 0,
				'max'         => 10000,
				'step'        => 1,
				'default'     => 300,
				'selectors'   => [
					'{{WRAPPER}} .bwdsb-style-common .content-wrappersss' => 'flex: 1 0 {{SIZE}}px!important',
				],
				'condition' => [
					'bwdsb_switch_breakpoint!' => '',
                    'bwdsb_switch_layout_style' => 'flex',
					'bwdsb_switch_layout_style_flex' => '',
				],
			]
		);
        $this->add_control(
			'bwdsb_switch_item_numbs',
			[
				'label'       => esc_html__('Item Numbers', 'bwdsb-switch-backgroundtd'),
                'description' => esc_html__( 'Go to the [ Switch Item Repeater ] tab and count the repeated items. Now, this count value write here, Only Number"3". Example: Now your repeated item number is #3.', 'bwdsb-switch-backgroundtd' ),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 0,
				'max'         => 10000,
				'step'        => 1,
				'default'     => 3,
				'condition' => [
					'bwdsb_switch_breakpoint!' => '',
                    'bwdsb_switch_layout_style' => 'flex',
					'bwdsb_switch_layout_style_flex' => '',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'bwdsb_call_content_section',
			[
				'label' => esc_html__( 'Switch Item Repeater', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$bwdsb_repet = new \Elementor\Repeater();

		$bwdsb_repet->add_control(
			'bwdsb_background_type',
			[
				'label' => esc_html__( 'Background Types', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'image',
				'options' => [
					'video' => esc_html__( 'Video', 'bwdsb-switch-backgroundtd' ),
					'image'  => esc_html__( 'Image', 'bwdsb-switch-backgroundtd' ),
					'color'  => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				],
			]
		);

		// Start Video Section
		$bwdsb_repet->add_control(
			'bwdsb_bg_video_type',
			[
				'label' => esc_html__( 'Video Types', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'mp4',
				'options' => [
					'youtube' => esc_html__( 'YouTube', 'bwdsb-switch-backgroundtd' ),
					'mp4'  => esc_html__( 'mp4', 'bwdsb-switch-backgroundtd' ),
				],
				'condition' => [
					'bwdsb_background_type' => 'video'
				],
			]
		);
		// mp4 Video
		$bwdsb_repet->add_control(
			'bwdsb_mp4_video_url',
			[
				'label' => esc_html__( 'mp4 Video Url', 'bwdsb-switch-backgroundtd' ),
				'label_block' => true,
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'video.mp4', 'bwdsb-switch-backgroundtd' ),
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'mp4',
				],
				'ai' => [
					'active' => false,
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_mp4_video_sound_switch',
			[
				'label' => esc_html__( 'mp4 Video Sound?', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bwdsb-switch-backgroundtd' ),
				'label_off' => esc_html__( 'Hide', 'bwdsb-switch-backgroundtd' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'mp4',
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_mp4_video_loop_switch',
			[
				'label' => esc_html__( 'mp4 Video Loop?', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bwdsb-switch-backgroundtd' ),
				'label_off' => esc_html__( 'Hide', 'bwdsb-switch-backgroundtd' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'mp4',
				],
			]
		);
		// YouTube Video
		$bwdsb_repet->add_control(
			'bwdsb_youtube_video_url',
			[
				'label' => esc_html__( 'YouTube Embed Url', 'bwdsb-switch-backgroundtd' ),
				'label_block' => true,
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'https://www.youtube.com/embed/MLpWrANjFbI?si=zN8QS0Ma2j1Wui94',
				'placeholder' => esc_html__( 'YouTube Embed Url', 'bwdsb-switch-backgroundtd' ),
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'youtube',
				],
				'ai' => [
					'active' => false,
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_youtube_video_sound_switch',
			[
				'label' => esc_html__( 'YouTube Video Sound?', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bwdsb-switch-backgroundtd' ),
				'label_off' => esc_html__( 'Hide', 'bwdsb-switch-backgroundtd' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'youtube',
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_youtube_video_loop_switch',
			[
				'label' => esc_html__( 'YouTube Video Loop?', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bwdsb-switch-backgroundtd' ),
				'label_off' => esc_html__( 'Hide', 'bwdsb-switch-backgroundtd' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'bwdsb_background_type' => 'video',
					'bwdsb_bg_video_type' => 'youtube',
				],
			]
		);
		// End Video Section

		// Start Image Section
		$bwdsb_repet->add_control(
			'bwdsb_switch_image',
			[
				'label' => esc_html__( 'Choose Image', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'bwdsb_background_type' => 'image'
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_switch_image_position',
			[
				'label' => esc_html__( 'Image Position', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'center center',
				'options' => [
					'left top'  => esc_html__( 'Left Top', 'bwdsb-switch-backgroundtd' ),
					'left center' => esc_html__( 'Left Center', 'bwdsb-switch-backgroundtd' ),
					'left bottom' => esc_html__( 'Left Bottom', 'bwdsb-switch-backgroundtd' ),
					'right top'  => esc_html__( 'Right Top', 'bwdsb-switch-backgroundtd' ),
					'right center' => esc_html__( 'Right Center', 'bwdsb-switch-backgroundtd' ),
					'right bottom' => esc_html__( 'Right Bottom', 'bwdsb-switch-backgroundtd' ),
					'center top'  => esc_html__( 'Center Top', 'bwdsb-switch-backgroundtd' ),
					'center center' => esc_html__( 'Center Center', 'bwdsb-switch-backgroundtd' ),
					'center bottom' => esc_html__( 'Center Bottom', 'bwdsb-switch-backgroundtd' ),
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .section-background' => 'background-position: {{VALUE}}!important;',
				],
				'condition' => [
					'bwdsb_background_type' => 'image'
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_switch_image_display_size',
			[
				'label' => esc_html__( 'Image Display Size', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'cover',
				'options' => [
					'auto'  => esc_html__( 'Auto', 'bwdsb-switch-backgroundtd' ),
					'cover' => esc_html__( 'Cover', 'bwdsb-switch-backgroundtd' ),
					'contain' => esc_html__( 'Contain', 'bwdsb-switch-backgroundtd' ),
					'custom' => esc_html__( 'Custom', 'bwdsb-switch-backgroundtd' ),
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .section-background' => 'background-size: {{VALUE}}!important;',
				],
				'condition' => [
					'bwdsb_background_type' => 'image'
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_switch_image_display_size_custom',
			[
				'label' => esc_html__( 'Width', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .section-background' => 'background-size: {{SIZE}}{{UNIT}} auto !important;',
				],
				'condition' => [
					'bwdsb_switch_image_display_size' => 'custom',
					'bwdsb_background_type' => 'image',
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_switch_image_X_position',
			[
				'label' => esc_html__( 'Image X Position', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => -10000,
						'max' => 10000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss .background_img' => 'left: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'bwdsb_background_type' => 'image'
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb_switch_image_Y_position',
			[
				'label' => esc_html__( 'Image Y Position', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => -10000,
						'max' => 10000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss .background_img' => 'top: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'bwdsb_background_type' => 'image'
				],
			]
		);
		// End Image Section

		// Start Color Section
		$bwdsb_repet->add_control(
			'bwdsb__item_bg_type',
			[
				'label' => esc_html__( 'Background Type', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'solid'  => esc_html__( 'Solid', 'bwdsb-switch-backgroundtd' ),
					'gradient'  => esc_html__( 'Gradient', 'bwdsb-switch-backgroundtd' ),
				],
				'condition' => [
					'bwdsb_background_type' => 'color',
				],
			]
		);
		$bwdsb_repet->add_control(
			'bwdsb__item_bg_type_solid',
			[
				'label' => esc_html__( 'Solid Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss .content-wrapper' => 'Background-color: {{VALUE}}',
				],
				'condition' => [
					'bwdsb_background_type' => 'color',
					'bwdsb__item_bg_type' => 'solid'
				],
			]
		);
		$bwdsb_repet->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'bwdsb__item_bg_type_gradient',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss .content-wrapper',
				'condition' => [
					'bwdsb_background_type' => 'color',
					'bwdsb__item_bg_type' => 'gradient'
				],
			]
		);
		// End Color Section

		// Start Vimeo Section
		// End Vimeo Section

		$bwdsb_repet->add_control(
			'bwdsb_content_animations_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		//content amination
		$bwdsb_repet->add_control(
			'bwdsb_content_animations',
			[
				'label'     => esc_html__('Content Animation', 'bwdsb-switch-backgroundtd'),
				'type'      => Controls_Manager::SELECT,
				'default' => '',
				'options'   => [
					'' => esc_html__('Default', 'bwdsb-switch-backgroundtd'),
					'bounce' => esc_html__('Bounce', 'bwdsb-switch-backgroundtd'),
					'bounceIn' => esc_html__('BounceIn', 'bwdsb-switch-backgroundtd'),
					'bounceOut' => esc_html__('BounceOut', 'bwdsb-switch-backgroundtd'),
					'bounceInUp' => esc_html__('bounceInUp', 'bwdsb-switch-backgroundtd'),
					'bounceInDown' => esc_html__('bounceInDown', 'bwdsb-switch-backgroundtd'),
					'bounceInLeft' => esc_html__('bounceInLeft', 'bwdsb-switch-backgroundtd'),
					'bounceInRight' => esc_html__('bounceInRight', 'bwdsb-switch-backgroundtd'),
					'backInUp' => esc_html__('backInUp', 'bwdsb-switch-backgroundtd'),
					'backInDown' => esc_html__('backInDown', 'bwdsb-switch-backgroundtd'),
					'backInLeft' => esc_html__('backInLeft', 'bwdsb-switch-backgroundtd'),
					'backInRight' => esc_html__('backInRight', 'bwdsb-switch-backgroundtd'),
					'flip' => esc_html__('Flip', 'bwdsb-switch-backgroundtd'),
					'flipInX' => esc_html__('FlipInX', 'bwdsb-switch-backgroundtd'),
					'flipInY' => esc_html__('FlipInY', 'bwdsb-switch-backgroundtd'),
					'fadeIn' => esc_html__('fadeIn', 'bwdsb-switch-backgroundtd'),
					'fadeOut' => esc_html__('FadeOut', 'bwdsb-switch-backgroundtd'),
					'fadeInUp' => esc_html__('fadeInUp', 'bwdsb-switch-backgroundtd'),
					'fadeInDown' => esc_html__('fadeInDown', 'bwdsb-switch-backgroundtd'),
					'fadeInUpBig' => esc_html__('fadeInUpBig', 'bwdsb-switch-backgroundtd'),
					'fadeInLeft' => esc_html__('fadeInLeft', 'bwdsb-switch-backgroundtd'),
					'fadeInRight' => esc_html__('fadeInRight', 'bwdsb-switch-backgroundtd'),
					'fadeInRightBig' => esc_html__('fadeInRightBig', 'bwdsb-switch-backgroundtd'),
					'fadeInBottomRight' => esc_html__('fadeInBottomRight', 'bwdsb-switch-backgroundtd'),
					'fadeInBottomLeft' => esc_html__('fadeInBottomLeft', 'bwdsb-switch-backgroundtd'),
					'fadeInTopRight' => esc_html__('fadeInTopRight', 'bwdsb-switch-backgroundtd'),
					'fadeInTopLeft' => esc_html__('fadeInTopLeft', 'bwdsb-switch-backgroundtd'),
					'rotateIn' => esc_html__('RotateIn', 'bwdsb-switch-backgroundtd'),
					'rotateOut' => esc_html__('RotateOut', 'bwdsb-switch-backgroundtd'),
					'rotateInUpRight' => esc_html__('rotateInUpRight', 'bwdsb-switch-backgroundtd'),
					'rotateInUpLeft' => esc_html__('rotateInUpLeft', 'bwdsb-switch-backgroundtd'),
					'rotateInDownRight' => esc_html__('rotateInDownRight', 'bwdsb-switch-backgroundtd'),
					'rotateInDownLeft' => esc_html__('rotateInDownLeft', 'bwdsb-switch-backgroundtd'),
					'hinge' => esc_html__('Hinge', 'bwdsb-switch-backgroundtd'),
					'zoomIn' => esc_html__('ZoomIn', 'bwdsb-switch-backgroundtd'),
					'zoomOut' => esc_html__('ZoomOut', 'bwdsb-switch-backgroundtd'),
					'zoomInUp' => esc_html__('zoomInUp', 'bwdsb-switch-backgroundtd'),
					'zoomInRight' => esc_html__('zoomInRight', 'bwdsb-switch-backgroundtd'),
					'zoomInLeft' => esc_html__('zoomInLeft', 'bwdsb-switch-backgroundtd'),
					'zoomInDown' => esc_html__('zoomInDown', 'bwdsb-switch-backgroundtd'),
					'slideInUp' => esc_html__('SlideInUp', 'bwdsb-switch-backgroundtd'),
					'slideInRight' => esc_html__('slideInRight', 'bwdsb-switch-backgroundtd'),
					'slideInLeft' => esc_html__('slideInLeft', 'bwdsb-switch-backgroundtd'),
					'slideInDown' => esc_html__('slideInDown', 'bwdsb-switch-backgroundtd'),
					'flash' => esc_html__('Flash', 'bwdsb-switch-backgroundtd'),
					'rollIn' => esc_html__('rollIn', 'bwdsb-switch-backgroundtd'),
					'pulse' => esc_html__('Pulse', 'bwdsb-switch-backgroundtd'),
					'rubberBand' => esc_html__('RubberBand', 'bwdsb-switch-backgroundtd'),
					'shakeX' => esc_html__('ShakeX', 'bwdsb-switch-backgroundtd'),
					'shakeY' => esc_html__('ShakeY', 'bwdsb-switch-backgroundtd'),
					'headShake' => esc_html__('HeadShake', 'bwdsb-switch-backgroundtd'),
					'swing' => esc_html__('Swing', 'bwdsb-switch-backgroundtd'),
					'tada' => esc_html__('Tada', 'bwdsb-switch-backgroundtd'),
					'wobble' => esc_html__('Wobble', 'bwdsb-switch-backgroundtd'),
					'jello' => esc_html__('Jello', 'bwdsb-switch-backgroundtd'),
					'heartBeat' => esc_html__('HeartBeat', 'bwdsb-switch-backgroundtd'),
					'jackInTheBox' => esc_html__('JackInTheBox', 'bwdsb-switch-backgroundtd'),
					'lightSpeedInLeft' => esc_html__('lightSpeedInLeft', 'bwdsb-switch-backgroundtd'),
					'lightSpeedInRight' => esc_html__('lightSpeedInRight', 'bwdsb-switch-backgroundtd'),
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss.active .content-inner-wrapper' => 'animation-name: {{VALUE}}!important;',
				],
			]
		);

		//content_animation_speed
		$bwdsb_repet->add_control(
			'bwdsb_content_animation_speed',
			[
				'label' => __('Animation Speed (ms)', 'bwdsb-switch-backgroundtd'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['ms'],
				'range' => [
					'ms' => [
						'min' => 100,
						'max' => 5000,
						'step' => 50,
					],
				],
				'default' => [
					'unit' => 'ms',
					'size' => 1250,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.content-wrappersss.active .content-inner-wrapper' => 'animation-duration: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$bwdsb_repet->add_control(
            'bwdsb_button_popover',
            [
                'label' => __('Buttons', 'bwdsb-switch-backgroundtd'),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => __('None', 'bwdsb-switch-backgroundtd'),
                'label_on' => __('Custom', 'bwdsb-switch-backgroundtd'),
                'return_value' => 'yes',
            ]
        );
		$bwdsb_repet->start_popover();
			//button text
			$bwdsb_repet->add_control(
				'bwdsb_switch_btn_text', 
				[
					'label' => esc_html__( 'First Button Text', 'bwdsb-switch-backgroundtd' ),
					'type' => \Elementor\Controls_Manager::TEXT,	
					'label_block' => true,
					'dynamic' => [
						'active' => true,
					],
				]
			);
			//button link
			$bwdsb_repet->add_control(
				'bwdsb_switch_btn_link',
				[
					'label' => esc_html__( 'First Button Link', 'bwdsb-switch-backgroundtd' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://example.com', 'bwdsb-switch-backgroundtd' ),
					'label_block' => true,
					'show_external' => true,
					'default' => [
						'url' => 'https://bestwpdeveloper.com/',
						'is_external' => true,
						'nofollow' => true,
					],
					'dynamic' => [
						'active' => true,
					],
					'condition' => [
						'bwdsb_switch_btn_text!' => '',
					],
				]
			);
			//button text
			$bwdsb_repet->add_control(
				'bwdsb_switch_btn_text_next', 
				[
					'label' => esc_html__( 'Second Button Text', 'bwdsb-switch-backgroundtd' ),
					'type' => \Elementor\Controls_Manager::TEXT,	
					'label_block' => true,
					'dynamic' => [
						'active' => true,
					],
				]
			);
			//button link
			$bwdsb_repet->add_control(
				'bwdsb_switch_btn_link_next',
				[
					'label' => esc_html__( 'Second Button Link', 'bwdsb-switch-backgroundtd' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://example.com', 'bwdsb-switch-backgroundtd' ),
					'label_block' => true,
					'show_external' => true,
					'default' => [
						'url' => 'https://bestwpdeveloper.com/',
						'is_external' => true,
						'nofollow' => true,
					],
					'dynamic' => [
						'active' => true,
					],
					'condition' => [
						'bwdsb_switch_btn_text_next!' => '',
					],
				]
			);
		$bwdsb_repet->end_popover();

		$bwdsb_repet->add_control(
			'bwdsb_switch_title', 
			[
				'label' => esc_html__( 'Title', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::TEXT,	
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$bwdsb_repet->add_control(
			'bwdsb_switch_description',
			[
				'label' => esc_html__( 'Description', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
			]
		);

		//main-repeater
		$this->add_control(
			'bwdsb_switch_main_repetater',
			[
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $bwdsb_repet->get_controls(),
				'default' => [
					[
						'bwdsb_switch_title' => esc_html__( 'Lorem ipsum dolor sit amet.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_description' => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_text' => esc_html__( 'Contact' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_btn_text_next' => esc_html__( 'Details' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link_next' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_image' => [
                            'url' => plugin_dir_url(__DIR__).'assets/public/image/default.jpg',
                        ],
					],
					[
						'bwdsb_switch_title' => esc_html__( 'Lorem ipsum dolor sit amet.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_description' => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_text' => esc_html__( 'Contact' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_btn_text_next' => esc_html__( 'Details' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link_next' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_image' => [
                            'url' => plugin_dir_url(__DIR__).'assets/public/image/default.jpg',
                        ],
					],
					[
						'bwdsb_switch_title' => esc_html__( 'Lorem ipsum dolor sit amet.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_description' => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_text' => esc_html__( 'Contact' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_btn_text_next' => esc_html__( 'Details' , 'bwdsb-switch-backgroundtd' ),
						'bwdsb_switch_btn_link_next' => ['url' => 'https://bestwpdeveloper.com/'],
						'bwdsb_switch_image' => [
                            'url' => plugin_dir_url(__DIR__).'assets/public/image/default.jpg',
                        ],
					],
				],
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
			'bwdsb_common_section_style',
			[
				'label' => esc_html__( 'Common', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		//image-height
		$this->add_responsive_control(
			'bwdsb_commn_img_height',
			[
				'label' => esc_html__( 'Section Height', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 10000,
						'step' => 1,
					],
					'vh' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .content-wrapper' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		//alignment
		$this->add_responsive_control(
			'bwdsb_commn_alignment',
			[
				'label' => esc_html__( 'Alignment', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__( 'Left', 'bwdsb-switch-backgroundtd' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bwdsb-switch-backgroundtd' ),
						'icon' => 'eicon-text-align-center',
					],
					'end' => [
						'title' => esc_html__( 'Right', 'bwdsb-switch-backgroundtd' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .content-inner-wrapper' => 'text-align: {{VALUE}}',
					'{{WRAPPER}} .bwdsb-max-bttn' => 'justify-content: {{VALUE}}',
				],
				'toggle' => true,
			]
		);

		$this->start_controls_tabs(
			'bwdsb_common_style_tabs'
		);

		$this->start_controls_tab(
			'bwdsb_common_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_switch_comn_BG_type',
			[
				'label' => esc_html__( 'Background Type', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'solid'  => esc_html__( 'Solid', 'bwdsb-switch-backgroundtd' ),
					'gradient'  => esc_html__( 'Gradient', 'bwdsb-switch-backgroundtd' ),
				],
			]
		);

		$this->add_control(
			'bwdsb_switch_comn_BG_type_solid',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .content-wrappersss .content-wrapper' => 'Background: {{VALUE}}',
				],
				'condition' => [
					'bwdsb_switch_comn_BG_type' => 'solid'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'bwdsb_commn_background',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .content-wrappersss .content-wrapper',
				'condition' => [
					'bwdsb_switch_comn_BG_type' => 'gradient'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_commn_border',
				'selector' => '{{WRAPPER}} .content-wrappersss .content-wrapper',
			]
		);

		$this->add_responsive_control(
			'bwdsb_commn_box_gap',
			[
				'label' => esc_html__( 'Box Gap', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 10000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-style-common' => 'gap: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
					'bwdsb_switch_layout_style' => 'flex',
				],
			]
		);

		//padding
		$this->add_responsive_control(
			'bwdsb_commn_padding',
			[
				'label' => esc_html__( 'Box Padding', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .content-inner-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();


		$this->start_controls_tab(
			'bwdsb_common_style_active_tab',
			[
				'label' => esc_html__( 'Active', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_switch_comn_BG_type_active',
			[
				'label' => esc_html__( 'Background Type', 'bwdsb-switch-backgroundtd' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'solid'  => esc_html__( 'Solid', 'bwdsb-switch-backgroundtd' ),
					'gradient'  => esc_html__( 'Gradient', 'bwdsb-switch-backgroundtd' ),
				],
			]
		);

		$this->add_control(
			'bwdsb_switch_comn_BG_type_solid_active',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .content-wrappersss.active .content-wrapper' => 'Background: {{VALUE}}',
				],
				'condition' => [
					'bwdsb_switch_comn_BG_type_active' => 'solid'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'bwdsb_commn_background_active',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .content-wrappersss.active .content-wrapper',
				'condition' => [
					'bwdsb_switch_comn_BG_type_active' => 'gradient'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_commn_border_active',
				'selector' => '{{WRAPPER}} .content-wrappersss.active .content-wrapper',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
		
		$this->end_controls_section();


		$this->start_controls_section(
			'bwdsb_title_section_style',
			[
				'label' => esc_html__( 'Title', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs(
			'bwdsb_hover_style_tabs'
		);

		$this->start_controls_tab(
			'bwdsb_hover_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_title_color',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'bwdsb_title_background',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'bwdsb_title_typo',
				'selector' => '{{WRAPPER}} .bwdsb-title',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_title_border',
				'selector' => '{{WRAPPER}} .bwdsb-title',
			]
		);
		$this->add_responsive_control(
			'bwdsb_title_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//padding
		$this->add_responsive_control(
			'bwdsb_title_padding',
			[
				'label' => esc_html__( 'Padding', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		//margin
		$this->add_responsive_control(
			'bwdsb_title_margin',
			[
				'label' => esc_html__( 'Margin', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();


		$this->start_controls_tab(
			'bwdsb_hover_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_title_color_hover',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'bwdsb_title_background_hover',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_title_border_hover',
				'selector' => '{{WRAPPER}} .bwdsb-title:hover',
			]
		);
		$this->add_responsive_control(
			'bwdsb_title_border_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-title:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();



		$this->start_controls_section(
			'bwdsb_desce_section_style',
			[
				'label' => esc_html__( 'Description', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs(
			'bwdsb_desce_hover_style_tabs'
		);

		$this->start_controls_tab(
			'bwdsb_desce_hover_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_desce_color',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'bwdsb_desce_background',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'bwdsb_desce_typo',
				'selector' => '{{WRAPPER}} .bwdsb-desc',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_desce_border',
				'selector' => '{{WRAPPER}} .bwdsb-desc',
			]
		);
		$this->add_responsive_control(
			'bwdsb_desce_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//padding
		$this->add_responsive_control(
			'bwdsb_desce_padding',
			[
				'label' => esc_html__( 'Padding', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		//margin
		$this->add_responsive_control(
			'bwdsb_desce_margin',
			[
				'label' => esc_html__( 'Margin', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();


		$this->start_controls_tab(
			'bwdsb_desce_hover_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'bwdsb-switch-backgroundtd' ),
			]
		);

		$this->add_control(
			'bwdsb_desce_color_hover',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'bwdsb_desce_background_hover',
			[
				'label' => esc_html__( 'Background Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_desce_border_hover',
				'selector' => '{{WRAPPER}} .bwdsb-desc:hover',
			]
		);
		$this->add_responsive_control(
			'bwdsb_desce_border_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-desc:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();







		$this->start_controls_section(
			'bwdsb_button_section_style',
			[
				'label' => esc_html__( 'Button', 'bwdsb-switch-backgroundtd' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'bwdsb_button_gap',
			[
				'label' => esc_html__( 'Button Gap', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 10000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-max-bttn' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'bwdsb_first_button_options',
			[
				'label' => esc_html__( 'First Button', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->start_controls_tabs(
			'bwdsb_button_style_tabs'
		);
		
		$this->start_controls_tab(
			'bwdsb_button_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bwdsb-switch-backgroundtd' ),
			]
		);

		//first-button-color
		$this->add_control(
			'bwdsb_FB_color',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev' => 'color: {{VALUE}}',
				],
			]
		);

		//first-button-background
		$this->add_control(
			'bwdsb_FB_bg',
			[
				'label' => esc_html__( 'Background', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'bwdsb_FB_typography',
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_FB_border',
				'label' => esc_html__( 'Border', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev',
			]
		);

		//first-button-Border Radius
		$this->add_responsive_control(
			'bwdsb_FB_radius',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-padding
		$this->add_responsive_control(
			'bwdsb_FB_padding',
			[
				'label' => esc_html__( 'Padding', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-box-shadow
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'bwdsb_FB_shadow',
				'label' => esc_html__( 'Box Shadow', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev',
			]
		);
		
		$this->end_controls_tab();

		$this->start_controls_tab(
			'bwdsb_button_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'bwdsb-switch-backgroundtd' ),
			]
		);

		//first-button-color
		$this->add_control(
			'bwdsb_FB_color_hover',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev:hover' => 'color: {{VALUE}}',
				],
			]
		);

		//first-button-background
		$this->add_control(
			'bwdsb_FB_bg_hover',
			[
				'label' => esc_html__( 'Background', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_FB_border_hover',
				'label' => esc_html__( 'Border', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev:hover',
			]
		);

		//first-button-Border Radius
		$this->add_responsive_control(
			'bwdsb_FB_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-box-shadow
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'bwdsb_FB_shadow_hover',
				'label' => esc_html__( 'Box Shadow', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-prev:hover',
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->add_control(
			'bwdsb_second_button_options',
			[
				'label' => esc_html__( 'Second Button', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->start_controls_tabs(
			'bwdsb_SB_button_style_tabs'
		);
		
		$this->start_controls_tab(
			'bwdsb_SB_button_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'bwdsb-switch-backgroundtd' ),
			]
		);

		//first-button-color
		$this->add_control(
			'bwdsb_SB_color',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next' => 'color: {{VALUE}}',
				],
			]
		);

		//first-button-background
		$this->add_control(
			'bwdsb_SB_bg',
			[
				'label' => esc_html__( 'Background', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'bwdsb_SB_typography',
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_SB_border',
				'label' => esc_html__( 'Border', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next',
			]
		);

		//first-button-Border Radius
		$this->add_responsive_control(
			'bwdsb_SB_radius',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-padding
		$this->add_responsive_control(
			'bwdsb_SB_padding',
			[
				'label' => esc_html__( 'Padding', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-box-shadow
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'bwdsb_SB_shadow',
				'label' => esc_html__( 'Box Shadow', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next',
			]
		);
		
		$this->end_controls_tab();

		$this->start_controls_tab(
			'bwdsb_SB_button_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'bwdsb-switch-backgroundtd' ),
			]
		);

		//first-button-color
		$this->add_control(
			'bwdsb_SB_color_hover',
			[
				'label' => esc_html__( 'Color', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next:hover' => 'color: {{VALUE}}',
				],
			]
		);

		//first-button-background
		$this->add_control(
			'bwdsb_SB_bg_hover',
			[
				'label' => esc_html__( 'Background', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'bwdsb_SB_border_hover',
				'label' => esc_html__( 'Border', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next:hover',
			]
		);

		//first-button-Border Radius
		$this->add_responsive_control(
			'bwdsb_SB_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'bwdsb-switch-backgroundtd' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//first-button-box-shadow
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'bwdsb_SB_shadow_hover',
				'label' => esc_html__( 'Box Shadow', 'bwdsb-switch-backgroundtd' ),
				'selector' => '{{WRAPPER}} .bwdsb-bttn.bwdsb-bttn-next:hover',
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();


		$this->end_controls_section();


		
	}

    protected function render(){

        $settings = $this->get_settings_for_display();

		$bwdsb_style_selection = $settings['bwdsb_select_style_selection'];

        $breakpoint_1 = $settings['bwdsb_switch_breakpoint'];
        $item_width = $settings['bwdsb_switch_item_width_breakpointout'];
        $item_numb = $settings['bwdsb_switch_item_numbs'];


		$media_query_1 = '@media only screen and (max-width: ' . $breakpoint_1 . 'px) {
			.bwdsb-style-common { overflow-x: auto; }
            .content-wrappersss .background_img { width: calc(' . $item_width .'px * ' . $item_numb . ')!important; }
		 }';
        ?>
                <style>
                    <?php echo $media_query_1; ?>
                </style>
        <?php
        ?>

        <?php

        if( 'style1' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style1 bwdsb-style-common">
            
                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">
                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>
                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>
                                <div class="bwdsb-max-bttn">
                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>
                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
					<?php if( 'color' !== $repet_switch['bwdsb_background_type'] ){ ?>
                    <div class="background_img">
						<?php if( 'image' == $repet_switch['bwdsb_background_type'] ){ ?>
                    	<div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
						<?php } elseif( 'video' == $repet_switch['bwdsb_background_type'] ){
							
							if( 'mp4' == $repet_switch['bwdsb_bg_video_type'] ){ ?>
							<video autoplay <?php echo esc_attr( ('yes' == $repet_switch['bwdsb_mp4_video_sound_switch']) ? '' : 'muted'); ?> <?php echo esc_attr( ('yes' == $repet_switch['bwdsb_mp4_video_loop_switch']) ? 'loop' : ''); ?> > <source src="<?php echo esc_url( $repet_switch['bwdsb_mp4_video_url'] ); ?>" type="video/mp4"> </video>
						<?php } elseif( 'youtube' == $repet_switch['bwdsb_bg_video_type'] ){ ?>
							<div style="position:relative; width:100%; padding-bottom:56.25%; height:0; overflow:hidden;">
								<iframe frameborder="0" allowfullscreen allow="autoplay" src="<?php echo esc_url($repet_switch['bwdsb_youtube_video_url']) ?>&autoplay=1<?php echo esc_attr( ('yes' == $repet_switch['bwdsb_youtube_video_sound_switch']) ? '' : '&mute=1'); ?><?php echo esc_attr( ('yes' == $repet_switch['bwdsb_youtube_video_loop_switch']) ? '&loop=1' : ''); ?>" style="position:absolute; top:0; left:0; width:100%; height:100%; object-fit: cover;"> </iframe>
							</div>
						<?php } } ?>
                    </div>
					<?php } ?>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style2' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style2 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style3' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style3 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style4' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style4 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style5' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style5 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style6' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style6 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style7' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style7 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style8' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style8 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style9' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style9 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style10' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style10 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style11' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style11 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style12' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style12 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style13' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style11 bwdsb-style13 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                        
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        } elseif( 'style14' === $bwdsb_style_selection ) { ?>
            <div class="bwdsb-style14 bwdsb-style-common">

                <?php if ( $settings['bwdsb_switch_main_repetater'] ) { 
                    foreach (  $settings['bwdsb_switch_main_repetater'] as $repet_switch ) {
                ?>
                <div class="content-wrappersss elementor-repeater-item-<?php echo esc_attr( $repet_switch['_id'] ); ?>">
                    <div class="content-wrapper">
                        <div class="content-inner-wrapper">
                            <div class="content-inner-wrapper-extra">

                                <?php if (!empty($repet_switch['bwdsb_switch_title'])) : ?>
                                <div class="bwdsb-title"><?php echo esc_html( $repet_switch['bwdsb_switch_title'] );?></div>
                                <?php endif; ?>

                                <?php if (!empty($repet_switch['bwdsb_switch_description'])) : ?>
                                <div class="bwdsb-desc"><?php echo esc_html( $repet_switch['bwdsb_switch_description'] );?></div>
                                <?php endif; ?>

                                <div class="bwdsb-max-bttn">

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-prev" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link']['url']) ? $repet_switch['bwdsb_switch_btn_link']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text']); ?></a>
                                    <?php endif; ?>

                                    <?php if (!empty($repet_switch['bwdsb_switch_btn_text_next'])) : ?>
                                    <a class="bwdsb-bttn bwdsb-bttn-next" href="<?php echo esc_url(isset($repet_switch['bwdsb_switch_btn_link_next']['url']) ? $repet_switch['bwdsb_switch_btn_link_next']['url'] : ''); ?>" <?php echo esc_attr(($repet_switch['bwdsb_switch_btn_link_next']['is_external']) ? 'target="_blank"' : ''); ?>><?php echo esc_html($repet_switch['bwdsb_switch_btn_text_next']); ?></a>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="background_img">
                        <div class="section-background" style="background: url(<?php echo esc_url( $repet_switch['bwdsb_switch_image']['url'] ); ?>);"></div>
                    </div>
                </div>
                <?php } } ?>
                <?php require 'bwdsb-MouseEvent.php' ; ?>
            </div>
            <?php
        }

    }

}